@@ -1,5 +1,5 @@
 /* digest.c --- Generate a CRAM-MD5 hex encoded HMAC-MD5 response string.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,6 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
 /* Get prototype. */
@@ -49,7 +53,7 @@
  */
 
 #if CRAM_MD5_DIGEST_LEN != 2*GC_MD5_DIGEST_SIZE
-# error MD5 length mismatch
+#error MD5 length mismatch
 #endif
 
 #define HEXCHAR(c) ((c & 0x0F) > 9 ? 'a' + (c & 0x0F) - 10 : '0' + (c & 0x0F))
