@@ -1,5 +1,5 @@
 /* error.c --- Error handling functionality.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -202,8 +202,10 @@ static struct
        N_("Authentication failed because a tls-unique CB was not provided.")),
   ERR (GSASL_NO_SAML20_IDP_IDENTIFIER,
        N_("Callback failed to provide SAML20 IdP identifier.")),
-  ERR (GSASL_NO_REDIRECT_URL,
-       N_("Callback failed to provide redirect URL."))
+  ERR (GSASL_NO_SAML20_REDIRECT_URL,
+       N_("Callback failed to provide SAML20 redirect URL.")),
+  ERR (GSASL_NO_OPENID20_REDIRECT_URL,
+       N_("Callback failed to provide OPENID20 redirect URL."))
 };
 /* *INDENT-ON* */
 
@@ -230,7 +232,7 @@ gsasl_strerror (int err)
 
   bindtextdomain (PACKAGE, LOCALEDIR);
 
-  if (err < 0 || err >= (sizeof (errors) / sizeof (errors[0])))
+  if (err < 0 || err >= (int) (sizeof (errors) / sizeof (errors[0])))
     return _(unknown);
 
   p = errors[err].description;
@@ -263,7 +265,7 @@ gsasl_strerror (int err)
 const char *
 gsasl_strerror_name (int err)
 {
-  if (err < 0 || err >= (sizeof (errors) / sizeof (errors[0])))
+  if (err < 0 || err >= (int) (sizeof (errors) / sizeof (errors[0])))
     return NULL;
 
   return errors[err].name;
